@@ -22,6 +22,7 @@
 
 /**
  * SECTION:gesclip
+ * @title: GESClip
  * @short_description: Base Class for objects in a GESLayer
  *
  * A #GESClip is a 'natural' object which controls one or more
@@ -37,7 +38,8 @@
 
 #include <string.h>
 
-GList *ges_clip_create_track_elements_func (GESClip * clip, GESTrackType type);
+static GList *ges_clip_create_track_elements_func (GESClip * clip,
+    GESTrackType type);
 static gboolean _ripple (GESTimelineElement * element, GstClockTime start);
 static gboolean _ripple_end (GESTimelineElement * element, GstClockTime end);
 static gboolean _roll_start (GESTimelineElement * element, GstClockTime start);
@@ -141,6 +143,8 @@ _set_start (GESTimelineElement * element, GstClockTime start)
   GST_DEBUG_OBJECT (element, "Setting children start, (initiated_move: %"
       GST_PTR_FORMAT ")", container->initiated_move);
 
+  element->start = start;
+  g_object_notify (G_OBJECT (element), "start");
   container->children_control_mode = GES_CHILDREN_IGNORE_NOTIFIES;
   for (tmp = container->children; tmp; tmp = g_list_next (tmp)) {
     GESTimelineElement *child = (GESTimelineElement *) tmp->data;
@@ -156,7 +160,7 @@ _set_start (GESTimelineElement * element, GstClockTime start)
   }
   container->children_control_mode = GES_CHILDREN_UPDATE;
 
-  return TRUE;
+  return FALSE;
 }
 
 static gboolean
@@ -1017,7 +1021,6 @@ ges_clip_set_moving_from_layer (GESClip * clip, gboolean is_moving)
  * You might rather use the ges_clip_move_to_layer function to
  * move #GESClip-s from a layer to another.
  *
- *
  * Returns: %TRUE if @clip is currently moving from its current layer
  * %FALSE otherwize
  **/
