@@ -20,8 +20,8 @@
 
 #ifndef __GES_INTERNAL_H__
 #define __GES_INTERNAL_H__
-
 #include <gst/gst.h>
+#include <gst/pbutils/encoding-profile.h>
 #include <gio/gio.h>
 
 #include "ges-timeline.h"
@@ -34,7 +34,9 @@
 G_BEGIN_DECLS
 
 GST_DEBUG_CATEGORY_EXTERN (_ges_debug);
+#ifndef GST_CAT_DEFAULT
 #define GST_CAT_DEFAULT _ges_debug
+#endif
 
 /*  The first 2 NLE priorities are used for:
  *    0- The Mixing element
@@ -143,10 +145,10 @@ ges_asset_cache_put (GESAsset * asset, GTask *task);
 G_GNUC_INTERNAL gboolean
 ges_asset_cache_set_loaded(GType extractable_type, const gchar * id, GError *error);
 
-GESAsset*
+GST_EXPORT GESAsset*
 ges_asset_cache_lookup(GType extractable_type, const gchar * id);
 
-gboolean
+GST_EXPORT gboolean
 ges_asset_try_proxy (GESAsset *asset, const gchar *new_id);
 
 G_GNUC_INTERNAL gboolean
@@ -256,6 +258,7 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_encoding_profile(GESBaseXmlForma
                                                                  const gchar * description,
                                                                  GstCaps * format,
                                                                  const gchar * preset,
+                                                                 GstStructure * preset_properties,
                                                                  const gchar * preset_name,
                                                                  guint id,
                                                                  guint presence,
@@ -297,7 +300,10 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_control_binding (GESBaseXmlForma
 
 G_GNUC_INTERNAL gboolean set_property_foreach                   (GQuark field_id,
                                                                  const GValue * value,
-                                                                 GObject * object);;
+                                                                 GObject * object);
+
+G_GNUC_INTERNAL GstElement * get_element_for_encoding_profile   (GstEncodingProfile *prof,
+                                                                 GstElementFactoryListType type);
 
 /* Function to initialise GES */
 G_GNUC_INTERNAL void _init_standard_transition_assets        (void);
