@@ -22,6 +22,7 @@
 
 /**
  * SECTION:geslayer
+ * @title: GESLayer
  * @short_description: Non-overlapping sequence of GESClip
  *
  * Responsible for the ordering of the various contained Clip(s). A
@@ -267,6 +268,8 @@ ges_layer_resync_priorities (GESLayer * layer)
 {
   gint min_source_prios;
 
+  g_return_val_if_fail (GES_IS_LAYER (layer), FALSE);
+
   GST_INFO_OBJECT (layer, "Resync priorities (prio: %d)",
       layer->priv->priority);
 
@@ -307,7 +310,6 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, NewAssetUData * udata)
 
     GST_ERROR ("Asset could not be created for uri %s, error: %s",
         ges_asset_get_id (asset), error->message);
-
   } else {
     GESProject *project = udata->layer->timeline ?
         GES_PROJECT (ges_extractable_get_asset (GES_EXTRACTABLE
@@ -315,10 +317,15 @@ new_asset_cb (GESAsset * source, GAsyncResult * res, NewAssetUData * udata)
     ges_extractable_set_asset (GES_EXTRACTABLE (udata->clip), asset);
 
     ges_project_add_asset (project, asset);
+
+    /* clip was already ref-sinked when creating udata,
+     * gst_layer_add_clip() creates a new ref as such and
+     * below we unref the ref from udata */
     ges_layer_add_clip (udata->layer, udata->clip);
   }
 
   gst_object_unref (asset);
+  gst_object_unref (udata->clip);
   g_slice_free (NewAssetUData, udata);
 }
 
@@ -337,6 +344,8 @@ ges_layer_get_duration (GESLayer * layer)
   GList *tmp;
   GstClockTime duration = 0;
 
+  g_return_val_if_fail (GES_IS_LAYER (layer), 0);
+
   for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
     duration = MAX (duration, _END (tmp->data));
   }
@@ -355,7 +364,7 @@ ges_layer_get_duration (GESLayer * layer)
  * removed. If you wish to use the @clip after this function, make sure you
  * call gst_object_ref() before removing it from the @layer.
  *
- * Returns: TRUE if the clip could be removed, FALSE if the layer does
+ * Returns: %TRUE if the clip could be removed, %FALSE if the layer does
  * not want to remove the clip.
  */
 gboolean
@@ -524,7 +533,7 @@ ges_layer_is_empty (GESLayer * layer)
 /**
  * ges_layer_add_clip:
  * @layer: a #GESLayer
- * @clip: (transfer full): the #GESClip to add.
+ * @clip: (transfer floating): the #GESClip to add.
  *
  * Adds the given clip to the layer. Sets the clip's parent, and thus
  * takes ownership of the clip.
@@ -555,6 +564,7 @@ ges_layer_add_clip (GESLayer * layer, GESClip * clip)
   current_layer = ges_clip_get_layer (clip);
   if (G_UNLIKELY (current_layer)) {
     GST_WARNING ("Clip %p already belongs to another layer", clip);
+    gst_object_ref_sink (clip);
     gst_object_unref (current_layer);
 
     return FALSE;
@@ -565,7 +575,7 @@ ges_layer_add_clip (GESLayer * layer, GESClip * clip)
     gchar *id;
     NewAssetUData *mudata = g_slice_new (NewAssetUData);
 
-    mudata->clip = clip;
+    mudata->clip = gst_object_ref_sink (clip);
     mudata->layer = layer;
 
     GST_DEBUG_OBJECT (layer, "%" GST_PTR_FORMAT " as no reference to any "
@@ -593,11 +603,10 @@ ges_layer_add_clip (GESLayer * layer, GESClip * clip)
     ges_extractable_set_asset (GES_EXTRACTABLE (clip), asset);
 
     g_slice_free (NewAssetUData, mudata);
+  } else {
+    gst_object_ref_sink (clip);
   }
 
-
-  gst_object_ref_sink (clip);
-
   /* Take a reference to the clip and store it stored by start/priority */
   priv->clips_start = g_list_insert_sorted (priv->clips_start, clip,
       (GCompareFunc) element_start_compare);
@@ -682,8 +691,6 @@ ges_layer_add_asset (GESLayer * layer,
   }
 
   if (!ges_layer_add_clip (layer, clip)) {
-    gst_object_unref (clip);
-
     return NULL;
   }
 
@@ -725,6 +732,8 @@ ges_layer_set_timeline (GESLayer * layer, GESTimeline * timeline)
 {
   GList *tmp;
 
+  g_return_if_fail (GES_IS_LAYER (layer));
+
   GST_DEBUG ("layer:%p, timeline:%p", layer, timeline);
 
   for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
@@ -733,3 +742,43 @@ ges_layer_set_timeline (GESLayer * layer, GESTimeline * timeline)
 
   layer->timeline = timeline;
 }
+
+/**
+ * ges_layer_get_clips_in_interval:
+ * @layer: a #GESLayer
+ * @start: start of the interval
+ * @end: end of the interval
+ *
+ * Gets the clips which appear between @start and @end on @layer.
+ *
+ * Returns: (transfer full) (element-type GESClip): a #GList of clips intersecting [@start, @end) interval on @layer.
+ */
+GList *
+ges_layer_get_clips_in_interval (GESLayer * layer, GstClockTime start,
+    GstClockTime end)
+{
+  GList *tmp;
+  GList *intersecting_clips = NULL;
+  GstClockTime clip_start, clip_end;
+  gboolean clip_intersects;
+
+  g_return_val_if_fail (GES_IS_LAYER (layer), NULL);
+
+  for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
+    clip_intersects = FALSE;
+    clip_start = ges_timeline_element_get_start (tmp->data);
+    clip_end = clip_start + ges_timeline_element_get_duration (tmp->data);
+    if (start <= clip_start && clip_start < end)
+      clip_intersects = TRUE;
+    else if (start < clip_end && clip_end <= end)
+      clip_intersects = TRUE;
+    else if (clip_start < start && clip_end > end)
+      clip_intersects = TRUE;
+
+    if (clip_intersects)
+      intersecting_clips =
+          g_list_insert_sorted (intersecting_clips, tmp->data,
+          (GCompareFunc) element_start_compare);
+  }
+  return intersecting_clips;
+}
