@@ -37,6 +37,7 @@ G_BEGIN_DECLS
 
 typedef struct _GESProjectPrivate GESProjectPrivate;
 
+GST_EXPORT
 GType ges_project_get_type (void);
 
 struct _GESProject
@@ -57,6 +58,8 @@ struct _GESProjectClass
   /* Signals */
   void     (*asset_added)    (GESProject * self,
                               GESAsset   * asset);
+  void     (*asset_loading)  (GESProject * self,
+                              GESAsset   * asset);
   void     (*asset_removed)  (GESProject * self,
                               GESAsset   * asset);
   gchar *  (*missing_uri)    (GESProject * self,
@@ -72,39 +75,53 @@ struct _GESProjectClass
   gpointer _ges_reserved[GES_PADDING];
 };
 
+GST_EXPORT
 gboolean  ges_project_add_asset    (GESProject* project,
                                     GESAsset *asset);
+GST_EXPORT
 gboolean  ges_project_remove_asset (GESProject *project,
                                     GESAsset * asset);
+GST_EXPORT
 GList   * ges_project_list_assets  (GESProject * project,
                                     GType filter);
+GST_EXPORT
 gboolean  ges_project_save         (GESProject * project,
                                     GESTimeline * timeline,
                                     const gchar *uri,
                                     GESAsset * formatter_asset,
                                     gboolean overwrite,
                                     GError **error);
+GST_EXPORT
 gboolean  ges_project_load         (GESProject * project,
                                     GESTimeline * timeline,
                                     GError **error);
-GESProject * ges_project_new       (const gchar *id);
+GST_EXPORT
+GESProject * ges_project_new       (const gchar *uri);
+GST_EXPORT
 gchar      * ges_project_get_uri   (GESProject *project);
+GST_EXPORT
 GESAsset   * ges_project_get_asset (GESProject * project,
                                     const gchar *id,
                                     GType extractable_type);
+GST_EXPORT
 gboolean ges_project_create_asset  (GESProject * project,
                                     const gchar *id,
                                     GType extractable_type);
 
+GST_EXPORT
 GESAsset * ges_project_create_asset_sync        (GESProject * project,
                                                  const gchar * id,
                                                  GType extractable_type,
                                                  GError **error);
+GST_EXPORT
 GList * ges_project_get_loading_assets          (GESProject * project);
 
+GST_EXPORT
 gboolean ges_project_add_encoding_profile       (GESProject *project,
                                                  GstEncodingProfile *profile);
+GST_EXPORT
 const GList *ges_project_list_encoding_profiles (GESProject *project);
+GST_EXPORT
 gboolean ges_add_missing_uri_relocation_uri    (const gchar * uri,
                                                 gboolean recurse);
 
