@@ -18,6 +18,7 @@
 
 /**
  * SECTION:gestimelineelement
+ * @title: GESTimelineElement
  * @short_description: Base Class for all elements that will be in a way or
  * another inside a GESTimeline.
  *
@@ -99,6 +100,13 @@ struct _GESTimelineElementPrivate
   GESTimelineElement *copied_from;
 };
 
+typedef struct
+{
+  GObject *child;
+  GParamSpec *arg;
+  GESTimelineElement *self;
+} EmitDeepNotifyInIdleData;
+
 static gboolean
 _lookup_child (GESTimelineElement * self, const gchar * prop_name,
     GObject ** child, GParamSpec ** pspec)
@@ -507,8 +515,8 @@ _set_name (GESTimelineElement * self, const gchar * wanted_name)
  * @self: a #GESTimelineElement
  * @parent: new parent of self
  *
- * Sets the parent of @self to @parent. The object's reference count will
- * be incremented, and any floating reference will be removed (see gst_object_ref_sink()).
+ * Sets the parent of @self to @parent. The parents needs to already
+ * own a hard reference on @self.
  *
  * Returns: %TRUE if @parent could be set or %FALSE when @self
  * already had a parent or @self and @parent are the same.
@@ -524,7 +532,8 @@ ges_timeline_element_set_parent (GESTimelineElement * self,
   if (self == parent) {
     GST_INFO_OBJECT (self, "Trying to add %p in itself, not a good idea!",
         self);
-
+    gst_object_ref_sink (self);
+    gst_object_unref (self);
     return FALSE;
   }
 
@@ -547,6 +556,8 @@ ges_timeline_element_set_parent (GESTimelineElement * self,
 had_parent:
   {
     GST_WARNING_OBJECT (self, "set parent failed, object already had a parent");
+    gst_object_ref_sink (self);
+    gst_object_unref (self);
     return FALSE;
   }
 }
@@ -656,16 +667,16 @@ ges_timeline_element_get_timeline (GESTimelineElement * self)
  * @self: a #GESTimelineElement
  * @start: the position in #GstClockTime
  *
- * Set the position of the object in its containing layer
+ * Set the position of the object in its containing layer.
  *
- * Note that if the timeline snap-distance property of the timeline containing
- * @self is set, @self will properly snap to its neighboors.
+ * Note that if the snapping-distance property of the timeline containing
+ * @self is set, @self will properly snap to the edges around @start.
  */
 void
 ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
 {
   GESTimelineElementClass *klass;
-  GESTimelineElement *toplevel_container;
+  GESTimelineElement *toplevel_container, *parent;
 
   g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
 
@@ -676,9 +687,15 @@ ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
       GST_TIME_ARGS (GES_TIMELINE_ELEMENT_START (self)), GST_TIME_ARGS (start));
 
   toplevel_container = ges_timeline_element_get_toplevel_parent (self);
+  parent = self->parent;
 
-  if (((gint64) (_START (toplevel_container) + start - _START (self))) < 0) {
-    GST_INFO_OBJECT (self, "Can not move the object as it would imply its"
+  /* FIXME This should not belong to GESTimelineElement */
+  if (toplevel_container &&
+      ((gint64) (_START (toplevel_container) + start - _START (self))) < 0 &&
+      parent
+      && GES_CONTAINER (parent)->children_control_mode == GES_CHILDREN_UPDATE) {
+    GST_INFO_OBJECT (self,
+        "Can not move the object as it would imply its "
         "container to have a negative start value");
 
     gst_object_unref (toplevel_container);
@@ -1122,7 +1139,31 @@ ges_timeline_element_copy (GESTimelineElement * self, gboolean deep)
     }
   }
 
+#if GLIB_CHECK_VERSION(2, 53, 1)
+  {
+    gint i;
+    GValue *values;
+    const gchar **names;
+    values = g_malloc0 (sizeof (GValue) * n_specs);
+    names = g_malloc0 (sizeof (gchar *) * n_specs);
+
+    for (i = 0; i < n_params; i++) {
+      values[i] = params[i].value;
+      names[i] = params[i].name;
+    }
+
+    ret =
+        GES_TIMELINE_ELEMENT (g_object_new_with_properties (G_OBJECT_TYPE
+            (self), n_params, names, values));
+    g_free (names);
+    g_free (values);
+  }
+#else
   ret = g_object_newv (G_OBJECT_TYPE (self), n_params, params);
+#endif
+
+  while (n_params--)
+    g_value_unset (&params[n_params].value);
 
   g_free (specs);
   g_free (params);
@@ -1171,7 +1212,6 @@ ges_timeline_element_get_toplevel_parent (GESTimelineElement * self)
  * ges_timeline_element_get_name:
  * @self: a #GESTimelineElement
  *
- *
  * Returns a copy of the name of @self.
  * Caller should g_free() the return value after usage.
  *
@@ -1190,7 +1230,6 @@ ges_timeline_element_get_name (GESTimelineElement * self)
  * @self: a #GESTimelineElement
  * @name: (allow-none): The name @self should take (if avalaible<)
  *
- *
  * Sets the name of object, or gives @self a guaranteed unique name (if name is NULL).
  * This function makes a copy of the provided name, so the caller retains ownership
  * of the name it sent.
@@ -1236,30 +1275,59 @@ had_timeline:
   }
 }
 
+static gboolean
+emit_deep_notify_in_idle (EmitDeepNotifyInIdleData * data)
+{
+  g_signal_emit (data->self, ges_timeline_element_signals[DEEP_NOTIFY], 0,
+      data->child, data->arg);
+
+  gst_object_unref (data->child);
+  g_param_spec_unref (data->arg);
+  gst_object_unref (data->self);
+  g_slice_free (EmitDeepNotifyInIdleData, data);
+
+  return FALSE;
+}
+
 static void
 child_prop_changed_cb (GObject * child, GParamSpec * arg
     G_GNUC_UNUSED, GESTimelineElement * self)
 {
-  g_signal_emit (self, ges_timeline_element_signals[DEEP_NOTIFY], 0,
-      child, arg);
+  EmitDeepNotifyInIdleData *data;
+
+  /* Emit "deep-notify" right away if in main thread */
+  if (g_main_context_acquire (g_main_context_default ())) {
+    g_main_context_release (g_main_context_default ());
+    g_signal_emit (self, ges_timeline_element_signals[DEEP_NOTIFY], 0,
+        child, arg);
+    return;
+  }
+
+  data = g_slice_new (EmitDeepNotifyInIdleData);
+
+  data->child = gst_object_ref (child);
+  data->arg = g_param_spec_ref (arg);
+  data->self = gst_object_ref (self);
+
+  g_idle_add ((GSourceFunc) emit_deep_notify_in_idle, data);
 }
 
 gboolean
 ges_timeline_element_add_child_property (GESTimelineElement * self,
     GParamSpec * pspec, GObject * child)
 {
-  gchar *signame = g_strconcat ("notify::", pspec->name, NULL);
+  gchar *signame;
   ChildPropHandler *handler;
 
   if (g_hash_table_contains (self->priv->children_props, pspec)) {
     GST_INFO_OBJECT (self, "Child property already exists: %s", pspec->name);
-
     return FALSE;
   }
 
   GST_DEBUG_OBJECT (self, "Adding child property: %" GST_PTR_FORMAT "::%s",
       child, pspec->name);
 
+  signame = g_strconcat ("notify::", pspec->name, NULL);
   handler = (ChildPropHandler *) g_slice_new0 (ChildPropHandler);
   handler->child = gst_object_ref (child);
   handler->handler_id =
@@ -1316,16 +1384,16 @@ void
 ges_timeline_element_set_child_property_by_pspec (GESTimelineElement * self,
     GParamSpec * pspec, GValue * value)
 {
-  GObject *child;
+  ChildPropHandler *handler;
 
   g_return_if_fail (GES_IS_TRACK_ELEMENT (self));
 
-  if (!ges_timeline_element_lookup_child (self, pspec->name, &child, &pspec))
+  handler = g_hash_table_lookup (self->priv->children_props, pspec);
+
+  if (!handler)
     goto not_found;
 
-  g_object_set_property (child, pspec->name, value);
-  gst_object_unref (child);
-  g_param_spec_unref (pspec);
+  g_object_set_property (handler->child, pspec->name, value);
 
   return;
 
