@@ -74,6 +74,7 @@
 #include <ges/ges-effect.h>
 #include <ges/ges-formatter.h>
 #include <ges/ges-pitivi-formatter.h>
+#include <ges/ges-command-line-formatter.h>
 #include <ges/ges-utils.h>
 #include <ges/ges-meta-container.h>
 #include <ges/ges-gerror.h>
@@ -84,10 +85,19 @@
 G_BEGIN_DECLS
 
 
-gboolean ges_init    (void);
-
-void     ges_version (guint * major, guint * minor, guint * micro,
-                      guint * nano);
+GST_EXPORT
+gboolean ges_init         (void);
+GST_EXPORT
+gboolean ges_init_check (int *argc, char **argv[], GError ** err);
+GST_EXPORT
+void     ges_deinit       (void);
+GST_EXPORT
+void     ges_version      (guint * major, guint * minor, guint * micro,
+                           guint * nano);
+GST_EXPORT GOptionGroup *
+ges_init_get_option_group (void);
+GST_EXPORT
+gboolean ges_validate_register_action_types (void);
 
 G_END_DECLS
 
